@@ -3,7 +3,7 @@ BEGIN {
   $Yeb::Application::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $Yeb::Application::VERSION = '0.005';
+  $Yeb::Application::VERSION = '0.006';
 }
 # ABSTRACT: Main Meta Class for a Yeb Application
 
@@ -16,6 +16,7 @@ use Class::Load ':all';
 use Path::Tiny qw( path );
 use Plack::Middleware::Debug;
 use List::Util qw( reduce );
+use Hash::Merge qw( merge );
 
 use Web::Simple ();
 
@@ -115,7 +116,7 @@ has yeb_functions => (
 			st => sub { $self->hash_accessor($self->cc->stash,@_) },
 			ex => sub { $self->hash_accessor($self->cc->export,@_) },
 			pa => sub { $self->hash_accessor_empty($self->cc->request->params,@_) },
-			has_pa => sub { $self->hash_accessor_has($self->cc->request->params,@_) },
+			pa_has => sub { $self->hash_accessor_has($self->cc->request->params,@_) },
 
 			text => sub {
 				$self->cc->content_type('text/plain');
@@ -191,6 +192,16 @@ sub add_middleware {
 	$self->y_main->prepend_to_chain( "" => sub { $middleware } );
 }
 
+sub merge_hashs {
+	my ( $self, @hashs ) = @_;
+	my $first = pop @hashs;
+	while (@hashs) {
+		my $next = pop @hashs;
+		$first = merge($first,$next);
+	}
+	return $first;
+}
+
 sub BUILD {
 	my ( $self ) = @_;
 
@@ -264,7 +275,7 @@ Yeb::Application - Main Meta Class for a Yeb Application
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SUPPORT
 
