@@ -3,7 +3,7 @@ BEGIN {
   $Yeb::Plugin::JSON::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $Yeb::Plugin::JSON::VERSION = '0.005';
+  $Yeb::Plugin::JSON::VERSION = '0.006';
 }
 # ABSTRACT: Yeb Plugin for JSON response
 
@@ -12,13 +12,23 @@ use JSON;
 
 has app => ( is => 'ro', required => 1 );
 
+sub get_vars {
+	my ( $self, $user_vars ) = @_;
+	my %stash = %{$self->app->cc->stash};
+	my %user = defined $user_vars ? %{$user_vars} : ();
+	return $self->app->merge_hashs(
+		$self->app->cc->export,
+		\%user
+	);
+}
+
 sub BUILD {
 	my ( $self ) = @_;
 	$self->app->register_function('json',sub {
-		my $data = shift;
-		$data = $self->app->current_context->stash->{x} unless defined $data;
+		my $user_vars = shift;
+		my $vars = $self->get_vars($user_vars);
 		$self->app->current_context->content_type('application/json');
-		$self->app->current_context->body(to_json($data,@_));
+		$self->app->current_context->body(to_json($vars,@_));
 		$self->app->current_context->response;
 	});
 }
@@ -35,7 +45,30 @@ Yeb::Plugin::JSON - Yeb Plugin for JSON response
 
 =head1 VERSION
 
-version 0.005
+version 0.006
+
+=head1 SYNOPSIS
+
+  package MyYeb;
+
+  use Yeb;
+
+  BEGIN {
+    plugin 'JSON';
+  }
+
+  r "/" => sub {
+    ex key => 'value';
+    json { other_key => 'value' };
+  };
+
+  1;
+
+=encoding utf8
+
+=head1 FRAMEWORK FUNCTIONS
+
+=head2 json
 
 =head1 SUPPORT
 
