@@ -6,22 +6,27 @@ BEGIN {
 	plugin 'Session';
 	plugin 'JSON';
 	plugin 'Xslate';
-	plugin 'Static';
+	plugin 'Static', default_root => root('htdocs');
 }
 
 xslate_path root('templates');
 
-static qr{^/}, root('htdocs');
+static qr{^/};
 static_404 qr{^/images/}, root('htdocs');
 
 r "/" => sub {
-	st->{page} = 'root';
+	st page => 'root';
 	xslate 'index';
 };
 
 r "/test" => sub {
-	st->{page} = 'test';
+	st page => 'test';
 	xslate 'index/test';
 };
 
+r "/json" => sub {
+  ex key => 'value';
+  json { other_key => 'value' };
+};
+
 1;
\ No newline at end of file
